@@ -1,56 +1,29 @@
+# Copyright 2019 The TensorFlow Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# =============================================================================
 from __future__ import annotations
 from typing import Sequence, Any, Optional, Callable
 
 import tensorflow as tf
+from tensorflow.keras.layers import Embedding, Dense, LayerNormalization, Dropout
 from tensorflow.keras.initializers import TruncatedNormal
-from tensorflow.keras.layers.experimental.preprocessing import TextVectorization
 
-from official.nlp.keras_nlp import layers
 import tensorflow_text as tftext
 
 from sknlp.activations import gelu
 
-from .bert_tokenization import BertTokenizationLayer
-
-
-@tf.keras.utils.register_keras_serializable(package="sknlp")
-class BertCharPreprocessingLayer(tf.keras.layers.Layer):
-    def __init__(
-        self,
-        vocab: Sequence[str],
-        cls_token: str = "[CLS]",
-        sep_token: str = "[SEP]",
-        **kwargs
-    ) -> None:
-        vocab: list = list(vocab)
-        self.cls_token = cls_token
-        self.sep_token = sep_token
-        if cls_token not in vocab:
-            vocab.append(cls_token)
-        if sep_token not in vocab:
-            vocab.append(sep_token)
-        if "[UNK]" in vocab:
-            idx = vocab.index("[UNK]")
-            vocab[idx] = "unk"
-        self.vocab = vocab
-        self.tokenizer = TextVectorization(
-            max_tokens=len(vocab),
-            standardize=None,
-            split=BertTokenizationLayer(cls_token=cls_token, sep_token=sep_token),
-        )
-        self.tokenizer.set_vocabulary(vocab[2:])
-        super().__init__(**kwargs)
-
-    def call(self, inputs: tf.Tensor) -> tf.Tensor:
-        return self.tokenizer(inputs)
-
-    def get_config(self) -> dict[str, Any]:
-        return {
-            **super().get_config(),
-            "vocab": self.vocab,
-            "cls_token": self.cls_token,
-            "sep_token": self.sep_token,
-        }
+from .transformer_encoder_block import TransformerEncoderBlock
 
 
 @tf.keras.utils.register_keras_serializable(package="sknlp")
@@ -60,22 +33,30 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
         vocab: Sequence[str],
         cls_token: str = "[CLS]",
         sep_token: str = "[SEP]",
-        **kwargs
+        max_length: int = 510,
+        return_offset: bool = False,
+        name: str = "bert_tokenize",
+        **kwargs,
     ) -> None:
         vocab: list = list(vocab)
         self.cls_token = cls_token
         self.sep_token = sep_token
+        self.max_length = max_length
         if cls_token not in vocab:
             vocab.append(cls_token)
         if sep_token not in vocab:
             vocab.append(sep_token)
-        self.vocab = vocab
+
+        self.max_chars_per_token = 1
         for i, token in enumerate(vocab):
             if token == cls_token:
                 self.cls_id = i
             if token == sep_token:
                 self.sep_id = i
-        super().__init__(**kwargs)
+            self.max_chars_per_token = max(self.max_chars_per_token, len(token))
+        self.vocab = vocab
+        self.return_offset = return_offset
+        super().__init__(name=name, **kwargs)
 
     def build(self, input_shape: tf.TensorShape) -> None:
         self.tokenizer = tftext.BertTokenizer(
@@ -87,23 +68,66 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
                     value_dtype=tf.int64,
                 ),
                 1,
-            )
+            ),
+            max_chars_per_token=self.max_chars_per_token,
         )
         super().build(input_shape)
 
-    def call(self, inputs: tf.Tensor) -> tf.Tensor:
-        token_ids = self.tokenizer.tokenize(inputs)
-        flatten_ids = token_ids.merge_dims(-2, -1)
-        cls_ids = tf.reshape(
-            tf.tile(tf.constant([self.cls_id], dtype=tf.int64), [token_ids.nrows()]),
-            [token_ids.nrows(), 1],
-        )
-        sep_ids = tf.reshape(
-            tf.tile(tf.constant([self.sep_id], dtype=tf.int64), [token_ids.nrows()]),
-            [token_ids.nrows(), 1],
-        )
-        ids = tf.concat([cls_ids, flatten_ids, sep_ids], axis=1)
-        return ids.to_tensor(0)
+    def call(self, inputs: tf.Tensor | list[tf.Tensor]) -> list[tf.Tensor]:
+        inputs = tf.nest.flatten(inputs)
+        trimmer = tftext.WaterfallTrimmer(self.max_length)
+        if len(inputs) == 1:
+            if self.return_offset:
+                (token_ids, starts, ends) = self.tokenizer.tokenize_with_offsets(
+                    inputs[0]
+                )
+                starts = starts.merge_dims(-2, -1)
+                ends = ends.merge_dims(-2, -1)
+            else:
+                token_ids = self.tokenizer.tokenize(inputs[0])
+            flatten_ids = token_ids.merge_dims(-2, -1)
+            ids, type_ids = tftext.combine_segments(
+                trimmer.trim([flatten_ids]),
+                start_of_sequence_id=self.cls_id,
+                end_of_segment_id=self.sep_id,
+            )
+            tensors: list[tf.Tensor] = [ids.to_tensor(), type_ids.to_tensor()]
+            if self.return_offset:
+                tensors.append(starts.to_tensor())
+                tensors.append(ends.to_tensor())
+            return tensors
+        elif len(inputs) == 2:
+            query, context = inputs
+            query_token_ids = self.tokenizer.tokenize(query)
+            if self.return_offset:
+                # TODO: 句对输入仅输出第二句的start和end索引是否合理,
+                #       需要根据具体任务设计判断, 如阅读理解
+                (
+                    context_token_ids,
+                    starts,
+                    ends,
+                ) = self.tokenizer.tokenize_with_offsets(context)
+                starts = starts.merge_dims(-2, -1)
+                ends = ends.merge_dims(-2, -1)
+            else:
+                context_token_ids = self.tokenizer.tokenize(context)
+            query_flatten_ids = query_token_ids.merge_dims(-2, -1)
+            context_flatten_ids = context_token_ids.merge_dims(-2, -1)
+            token_ids, type_ids = tftext.combine_segments(
+                trimmer.trim([query_flatten_ids, context_flatten_ids]),
+                start_of_sequence_id=self.cls_id,
+                end_of_segment_id=self.sep_id,
+            )
+
+            tensors: list[tf.Tensor] = [token_ids.to_tensor(), type_ids.to_tensor()]
+            if self.return_offset:
+                tensors.append(starts.to_tensor())
+                tensors.append(ends.to_tensor())
+            return tensors
+        else:
+            raise ValueError(
+                f"The length of inputs must be 1 or 2, bug get {len(inputs)}."
+            )
 
     def get_config(self) -> dict[str, Any]:
         return {
@@ -111,46 +135,12 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
             "vocab": self.vocab,
             "cls_token": self.cls_token,
             "sep_token": self.sep_token,
+            "return_offset": self.return_offset,
         }
 
 
 @tf.keras.utils.register_keras_serializable(package="sknlp")
-class BertPairPreprocessingLayer(BertPreprocessingLayer):
-    def call(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
-        query, context = inputs
-        query_token_ids = self.tokenizer.tokenize(query)
-        context_token_ids = self.tokenizer.tokenize(context)
-        query_flatten_ids = query_token_ids.merge_dims(-2, -1)
-        context_flatten_ids = context_token_ids.merge_dims(-2, -1)
-        cls_ids = tf.reshape(
-            tf.tile(
-                tf.constant([self.cls_id], dtype=tf.int64), [query_token_ids.nrows()]
-            ),
-            [query_token_ids.nrows(), 1],
-        )
-        sep_ids = tf.reshape(
-            tf.tile(
-                tf.constant([self.sep_id], dtype=tf.int64), [query_token_ids.nrows()]
-            ),
-            [query_token_ids.nrows(), 1],
-        )
-        query_ids = tf.concat([cls_ids, query_flatten_ids, sep_ids], axis=1)
-        context_ids = tf.concat([context_flatten_ids, sep_ids], axis=1)
-        type_ids = tf.concat(
-            [
-                tf.zeros_like(query_ids, dtype=tf.int64),
-                tf.ones_like(context_ids, dtype=tf.int64),
-            ],
-            axis=1,
-        )
-        return (
-            tf.concat([query_ids, context_ids], axis=1, name="token_ids").to_tensor(0),
-            type_ids.to_tensor(0),
-        )
-
-
-@tf.keras.utils.register_keras_serializable(package="sknlp")
-class BertEncodeLayer(tf.keras.layers.Layer):
+class BertLayer(tf.keras.layers.Layer):
     """
     copy from https://github.com/tensorflow/models/blob/v2.2.0/official/nlp/modeling/networks/transformer_encoder.py.
     """
@@ -172,8 +162,9 @@ class BertEncodeLayer(tf.keras.layers.Layer):
         initializer: tf.keras.initializers.Initializer = TruncatedNormal(stddev=0.02),
         share_layer: bool = False,
         cls_pooling: bool = True,
-        name: str = "bert_encode_layer",
-        **kwargs
+        enable_recompute_grad: bool = False,
+        name: str = "bert_layer",
+        **kwargs,
     ) -> None:
         if embedding_size is None:
             embedding_size = hidden_size
@@ -193,94 +184,119 @@ class BertEncodeLayer(tf.keras.layers.Layer):
         self.initializer = initializer
         self.share_layer = share_layer
         self.cls_pooling = cls_pooling
-        self.supports_masking = True
+        self.enable_recompute_grad = enable_recompute_grad
         super().__init__(name=name, **kwargs)
 
     def build(self, input_shape: tf.TensorShape) -> None:
         input_shape = input_shape[0]
-        self.embedding_layer = layers.OnDeviceEmbedding(
+        self.embedding_layer = Embedding(
             self.vocab_size,
             self.embedding_size,
-            initializer=self.initializer,
+            embeddings_initializer=self.initializer,
             name="word_embeddings",
         )
-        # Always uses dynamic slicing for simplicity.
-        self.position_embedding_layer = layers.PositionEmbedding(
+        self.position_embedding_layer = Embedding(
             self.max_sequence_length,
-            initializer=self.initializer,
+            self.embedding_size,
+            embeddings_initializer=self.initializer,
             name="position_embedding",
         )
-        self.type_embedding_layer = layers.OnDeviceEmbedding(
+        self.type_embedding_layer = Embedding(
             self.type_vocab_size,
             self.embedding_size,
-            initializer=self.initializer,
-            use_one_hot=True,
+            embeddings_initializer=self.initializer,
             name="type_embeddings",
         )
+        self.embedding_normalize_layer = LayerNormalization(
+            name="embeddings/layer_norm", axis=-1, epsilon=1e-12, dtype=tf.float32
+        )
+        self.embedding_dropout_layer = Dropout(
+            rate=self.dropout_rate, name="embeddings/dropout"
+        )
         if self.embedding_size != self.hidden_size:
             self.embedding_projection = tf.keras.layers.experimental.EinsumDense(
                 "...x,xy->...y",
                 output_shape=self.hidden_size,
                 bias_axes="y",
                 kernel_initializer=self.initializer,
-                name="embedding_projection",
+                name="embeddings/transform",
             )
         else:
             self.embedding_projection = None
-        self.normalize_layer = tf.keras.layers.LayerNormalization(
-            name="embeddings/layer_norm", axis=-1, epsilon=1e-12, dtype=tf.float32
-        )
-        self.embedding_dropout_layer = tf.keras.layers.Dropout(
-            rate=self.dropout_rate, name="embeddings/dropout"
-        )
+
         if self.share_layer:
-            self.shared_layer = layers.TransformerEncoderBlock(
+            self.shared_layer = TransformerEncoderBlock(
                 self.num_attention_heads,
                 self.intermediate_size,
                 self.activation,
                 output_dropout=self.dropout_rate,
                 attention_dropout=self.attention_dropout_rate,
                 kernel_initializer=self.initializer,
+                enable_recompute_grad=self.enable_recompute_grad,
                 name="transformer",
             )
         else:
             self.transformer_layers = []
             for i in range(self.num_layers):
-                layer = layers.TransformerEncoderBlock(
+                layer = TransformerEncoderBlock(
                     self.num_attention_heads,
                     self.intermediate_size,
                     self.activation,
                     output_dropout=self.dropout_rate,
                     attention_dropout=self.attention_dropout_rate,
                     kernel_initializer=self.initializer,
+                    enable_recompute_grad=self.enable_recompute_grad,
                     name="transformer/layer_%d" % i,
                 )
                 self.transformer_layers.append(layer)
 
         if self.cls_pooling:
-            self.cls_output_layer = tf.keras.layers.Dense(
+            self.cls_output_layer = Dense(
                 units=self.hidden_size,
                 activation="tanh",
                 kernel_initializer=self.initializer,
-                name="pooler_transform",
+                name="cls_pooler",
             )
+        self.lm_dense = Dense(
+            self.embedding_size,
+            activation=self.activation,
+            kernel_initializer=self.initializer,
+            name="lm/transform/dense",
+        )
+        self.lm_normalize_layer = LayerNormalization(
+            axis=-1, epsilon=1e-12, name="lm/transform/layer_norm"
+        )
+        self.lm_bias = self.add_weight(
+            "lm/output_bias",
+            shape=(self.vocab_size,),
+            initializer="zeros",
+        )
+        self.relationship_dense = Dense(
+            2, kernel_initializer=self.initializer, name="relationship"
+        )
         super().build(input_shape)
 
+    def compute_output_shape(
+        self, input_shape: list[tf.TensorShape]
+    ) -> list[tf.TensorShape]:
+        return super().compute_output_shape(input_shape)
+
     def call(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
-        token_ids, type_ids = inputs
-        mask = self.compute_mask(inputs, mask=None)[0]
+        token_ids, type_ids, attention_mask, logits_mask = inputs
+        # (batch_size, seq_len, embedding_size)
         word_embeddings = self.embedding_layer(token_ids)
-        position_embeddings = self.position_embedding_layer(word_embeddings)
+        # (1, seq_len)
+        position_ids = tf.range(tf.shape(token_ids)[-1])[None, ...]
+        # (1, seq_len, embedding_size)
+        position_embeddings = self.position_embedding_layer(position_ids)
+        # (batch_size, seq_len, embedding_size)
         type_embeddings = self.type_embedding_layer(type_ids)
-        embeddings = tf.keras.layers.Add()(
-            [word_embeddings, position_embeddings, type_embeddings]
-        )
-        embeddings = self.normalize_layer(embeddings)
+        embeddings = word_embeddings + position_embeddings + type_embeddings
+        embeddings = self.embedding_normalize_layer(embeddings)
         embeddings = self.embedding_dropout_layer(embeddings)
         if self.embedding_projection is not None:
             embeddings = self.embedding_projection(embeddings)
         data = embeddings
-        attention_mask = layers.SelfAttentionMask()(data, mask)
         encoder_outputs = []
         if self.share_layer:
             for _ in range(self.num_layers):
@@ -291,20 +307,24 @@ class BertEncodeLayer(tf.keras.layers.Layer):
                 data = layer([data, attention_mask])
                 encoder_outputs.append(data)
 
-        first_token_tensor = tf.keras.layers.Lambda(
-            lambda x: tf.squeeze(x[:, 0:1, :], axis=1)
-        )(encoder_outputs[-1])
+        first_token_tensor = encoder_outputs[-1][:, 0, :]
         cls_output = first_token_tensor
         if self.cls_pooling:
             cls_output = self.cls_output_layer(cls_output)
-        return [encoder_outputs, cls_output]
-
-    def compute_mask(
-        self, inputs: list[tf.Tensor], mask: Optional[tf.Tensor] = None
-    ) -> tf.Tensor:
-        if mask is not None:
-            return [mask for _ in range(self.num_layers)]
-        return [tf.math.not_equal(inputs[0], 0) for _ in range(self.num_layers)]
+        # (batch_size, mask_seq_len, dim)
+        token_encodings = tf.ragged.boolean_mask(
+            encoder_outputs[-1], tf.cast(logits_mask, tf.bool)
+        ).to_tensor()
+        # (batch_size, mask_seq_len, embedding_size)
+        lm_data = self.lm_dense(token_encodings)
+        lm_data = self.lm_normalize_layer(lm_data)
+        # (batch_size, mask_seq_len, vocab_size)
+        lm_logits = tf.nn.bias_add(
+            tf.matmul(lm_data, self.embedding_layer.embeddings, transpose_b=True),
+            self.lm_bias,
+        )
+        rel_logits = self.relationship_dense(cls_output)
+        return cls_output, encoder_outputs, lm_logits, rel_logits
 
     def get_config(self):
         return {
@@ -324,4 +344,5 @@ class BertEncodeLayer(tf.keras.layers.Layer):
             "initializer": self.initializer,
             "share_layer": self.share_layer,
             "cls_pooling": self.cls_pooling,
+            "enable_recompute_grad": self.enable_recompute_grad,
         }
\ No newline at end of file
