@@ -14,13 +14,13 @@ class RNNClassifier(DeepClassifier):
         classes: list[str],
         is_multilabel: bool = True,
         max_sequence_length: int = 100,
-        dropout: float = 0.5,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 128,
         fc_activation: str = "tanh",
         num_rnn_layers: int = 1,
         rnn_hidden_size: int = 512,
-        rnn_recurrent_dropout: float = 0.0,
+        rnn_dropout: float = 0.1,
+        rnn_recurrent_dropout: float = 0.5,
         text2vec: Optional[Text2vec] = None,
         **kwargs
     ):
@@ -35,9 +35,9 @@ class RNNClassifier(DeepClassifier):
             algorithm="rnn",
             **kwargs
         )
-        self.dropout = dropout
         self.num_rnn_layers = num_rnn_layers
         self.rnn_hidden_size = rnn_hidden_size
+        self.rnn_dropout = rnn_dropout
         self.rnn_recurrent_dropout = rnn_recurrent_dropout
 
     def build_encoding_layer(self, inputs: tf.Tensor) -> tf.Tensor:
@@ -47,7 +47,7 @@ class RNNClassifier(DeepClassifier):
             BiLSTM(
                 self.num_rnn_layers,
                 self.rnn_hidden_size,
-                dropout=self.dropout,
+                dropout=self.rnn_dropout,
                 recurrent_dropout=self.rnn_recurrent_dropout,
                 return_sequences=True,
             )(embeddings, mask),
@@ -56,10 +56,10 @@ class RNNClassifier(DeepClassifier):
 
     def build_intermediate_layer(self, inputs: list[tf.Tensor]) -> tf.Tensor:
         encodings, mask = inputs
-        if self.dropout:
+        if self.rnn_dropout:
             noise_shape = (None, 1, self.rnn_hidden_size * 2)
             encodings = tf.keras.layers.Dropout(
-                self.dropout,
+                self.rnn_dropout,
                 noise_shape=noise_shape,
                 name="encoding_dropout",
             )(encodings)
